import logging.config, os
import platform

__version__ = '0.1.0'


def __is_test_env():
    return os.environ.get('SPIDER_TEST', False) or platform.system() == "Windows"


def __get_endpoint():
    if __is_test_env():
        return "cn-shanghai.log.aliyuncs.com"
    else:
        return "cn-shanghai-intranet.log.aliyuncs.com"


conf = {'version': 1,
        'disable_existing_loggers': False,
        'formatters': {'rawformatter': {'class': 'logging.Formatter',
                                        'format': '%(message)s'}
                       },
        'handlers': {'sls_handler': {'()':
                                         'aliyun.log.QueuedLogHandler',
                                     'level': 'INFO',
                                     'formatter': 'rawformatter',

                                     # custom args:
                                     'end_point': os.environ.get('ALIYUN_LOG_ENDPOINT', __get_endpoint()),
                                     'access_key_id': os.environ.get('ALIYUN_LOG_ACCESSID', ''),
                                     'access_key': os.environ.get('ALIYUN_LOG_ACCESSKEY', ''),
                                     'project': os.environ.get('ALIYUN_LOG_PROJECT', 'spider-test'),
                                     'log_store': os.environ.get('ALIYUN_LOG_STORE', "gs-log"),
                                     'extract_json': True,
                                     'extract_json_prefix': 'spider_',
                                     }
                     },
        'loggers': {'sls': {'handlers': ['sls_handler', ],
                            'level': 'INFO',
                            'propagate': False}
                    }
        }
logging.config.dictConfig(conf)


def get_logger():
    return logging.getLogger("sls")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sls_json_fast']

package_data = \
{'': ['*']}

install_requires = \
['aliyun-log-python-sdk>=0.7,<0.8', 'protobuf>=3.4.0,<4.0.0']

setup_kwargs = {
    'name': 'sls-json-fast',
    'version': '0.1.2',
    'description': 'aliyun sls log python for json',
    'long_description': '# 阿里云日志服务 for JSON\n\n## 使用\n\n- `ALIYUN_LOG_ENDPOINT` 日志服务端点，默认根据环境自动配置内外网\n- `ALIYUN_LOG_ACCESSID` 阿里云 access id\n- `ALIYUN_LOG_ACCESSKEY` 阿里云 access key\n- `ALIYUN_LOG_PROJECT` 阿里云日志项目名\n- `ALIYUN_LOG_STORE` 阿里云日志存储库名',
    'author': 'JimZhang',
    'author_email': 'zzl22100048@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
